@@ -18,6 +18,7 @@ code for the first time here in its Python form.
 
 """
 from math import atan2, cos, fabs, pi, sin, sqrt
+from sgp4.alpha5 import to_alpha5
 
 deg2rad = pi / 180.0;
 _nan = float('NaN')
@@ -1340,9 +1341,16 @@ def sgp4init(
 
  	 # -------------------------------------------------------------------------
 
+     # The SGP4 library has changed `satn` from an integer to a string.
+     # But to avoid breaking our API contract with existing Python code,
+     # we are still willing to accept an integer.
+     if isinstance(satn, int):
+          satn = to_alpha5(satn)
+
      satrec.error = 0;
      satrec.operationmode = opsmode;
-     satrec.satnum = satn;
+     satrec.satnum_str = satn;
+     satrec.classification = 'U'  # so attribute is not missing in Python
 
      """
      // sgp4fix - note the following variables are also passed directly via satrec.
